@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
-# $Id: __init__.py 11012 2018-05-06 05:58:39Z Lavender $
+# $Id: __init__.py 11025 2018-05-09 16:00:59Z Lavender $
 #
 # Copyright (c) 2015 Nuwa Information Co., Ltd, All Rights Reserved.
 #
@@ -12,8 +12,8 @@
 # limitations under the License.
 #
 # $Author: Lavender $ (last)
-# $Date: 2018-05-06 13:58:39 +0800 (週日, 06 五月 2018) $
-# $Revision: 11012 $
+# $Date: 2018-05-10 00:00:59 +0800 (週四, 10 五月 2018) $
+# $Revision: 11025 $
 
 import os
 import warnings
@@ -76,6 +76,12 @@ def attachSettings(settingsDict):
     else:
         ZEPHYRUS_BLOG_ENABLE = False
 
+
+    if 'ZEPHYRUS_OSCAR_ENABLE' in settingsDict:
+        ZEPHYRUS_OSCAR_ENABLE = settingsDict['ZEPHYRUS_OSCAR_ENABLE']
+    else:
+        ZEPHYRUS_OSCAR_ENABLE = False
+
     #=========================================================================
     # Django plugins.
     ADDING_INSTALLED_APPS = [
@@ -88,7 +94,6 @@ def attachSettings(settingsDict):
         'Zephyrus.facebook',
         'drip',
         'Zephyrus.autoresponder',
-        'Zephyrus.comment',
     ]
 
     if ZEPHYRUS_BLOG_ENABLE:
@@ -104,6 +109,12 @@ def attachSettings(settingsDict):
             'taggit',
 
             'Zephyrus.blog_extension',
+            'Zephyrus.comment',
+        ]
+
+    if ZEPHYRUS_OSCAR_ENABLE:
+        ADDING_INSTALLED_APPS += [
+            'Zephyrus.cms_oscar',
         ]
 
     installed = settingsDict['INSTALLED_APPS']
