@@ -21,6 +21,8 @@ import hashlib
 import json
 import traceback
 
+import cms
+
 from lxml import etree
 from lxml.html import soupparser
 from lxml.html.soupparser import parse
@@ -77,7 +79,12 @@ BLOCK_TAGS = ['div',]
 
 # special ----------------------------------------------------------------------
 SKIP_BLOCK_TAG = ['a', 'span',] + VISUAL_TAGS
-ADD_COMMENT_TO_PREVIOUS = ['img', 'a',]
+
+if cms.__version__.startswith('3.5'):
+    ADD_COMMENT_TO_PREVIOUS = []
+else:    
+    ADD_COMMENT_TO_PREVIOUS = ['img', 'a',]
+
 JUMP_OFF_TAG = ['script', 'style', 'link',]
 CHANGE_WORD = {
     '{': '&#123;',
@@ -94,11 +101,12 @@ COMMENT = "The template was modified by Nuwainfo.com"
 LEGEL = "\n%s\n" % get_template('boilerplate/txt/Legel.txt').render()
 
 # cms --------------------------------------------------------------------------
-CMS_HEAD_FRONT_TAG = "{% load cms_tags menu_tags sekizai_tags staticfiles %}"
-CMS_HEAD_BACK_TAG = "{% render_block 'css' %}"
+CMS_HEAD_FRONT_TAG = ("{% load cms_tags menu_tags sekizai_tags staticfiles %}"
+                      "{% with '' as CMS_STATIC_DIR %}")
+CMS_HEAD_BACK_TAG = "{% endwith %}{% render_block 'css' %}"
 
-CMS_BODY_FRONT_TAG = "{% cms_toolbar %}"
-CMS_BODY_BACK_TAG = "{% render_block 'js' %}"
+CMS_BODY_FRONT_TAG = "{% cms_toolbar %}{% with '' as CMS_STATIC_DIR %}"
+CMS_BODY_BACK_TAG = "{% endwith %}{% render_block 'js' %}"
 
 CMS_PAGE_ATTRS_COMMENT = '''
     CMS page attribute
@@ -514,7 +522,8 @@ class Command(BaseCommand):
             head.insert(0, metaDescription)
         head.insert(0, comment) 
         head.insert(0, addJ)
-        head.insert(0, addContext)
+        if not cms.__version__.startswith('3.5'):
+            head.insert(0, addContext)
         head.insert(0, workAroundComment)
         head.insert(0, jq)
         head.insert(0, staticPathJs)
@@ -659,7 +668,8 @@ class Command(BaseCommand):
                     templatePath = "/" + href
                     content = content.replace(fileDict[path], templatePath)
                 else:
-                    staticPath = "{% static '" + path + "' %}"
+                    staticPath = \
+                        "{% static CMS_STATIC_DIR|add:'" + path + "' %}"
                     content = content.replace(fileDict[path], staticPath)
 
         with open(filePath, 'w') as f:
