@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
-# $Id: setup.py 10962 2018-04-03 06:45:05Z Lavender $
+# $Id: setup.py 11011 2018-05-06 04:26:57Z Lavender $
 #
 # Copyright (c) 2017 Nuwa Information Co., Ltd, All Rights Reserved.
 #
@@ -12,8 +12,8 @@
 # limitations under the License.
 #
 # $Author: Lavender $
-# $Date: 2018-04-03 14:45:05 +0800 (週二, 03 四月 2018) $
-# $Revision: 10962 $
+# $Date: 2018-05-06 12:26:57 +0800 (週日, 06 五月 2018) $
+# $Revision: 11011 $
 import os
 import sys
 import logging
@@ -90,17 +90,7 @@ def copyToPath(baseDir, templateDir, staticDir, mode):
                 index = len(os.path.join(SETUP_DIR, "static")) + 1
                 dst = os.path.join(staticDir, origin[index:])
             elif os.path.join(SETUP_DIR, "templates") in root:
-                result = os.path.splitext(origin)[0]
-                if mode == 'programmer':
-                    if result.endswith("_user"):
-                        continue
-                    dst = os.path.join(templateDir, f)
-                else:
-                    if not result.endswith("_user"):
-                        if not result.endswith("_tracking"):
-                            continue
-                    dst = os.path.join(
-                        templateDir, f.replace('_user.html', '.html'))
+                dst = os.path.join(templateDir, f)
             elif os.path.join(SETUP_DIR, "fixtures") in root:
                 index = len(os.path.join(SETUP_DIR, "fixtures")) + 1
                 dst = os.path.join(baseDir, "fixtures", origin[index:])
@@ -143,8 +133,6 @@ def writeSettings(settingsPath, templateDir, staticDir, hasCmsTemplate,
         index = None
                
         for template in os.listdir(path):
-            if "_user" in template:
-                continue
             if "_tracking" in template:
                 continue
             if template.lower() == 'index.html':
